summaryrefslogtreecommitdiffstats
path: root/kmymoney2/widgets/kmymoneycategory.cpp
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 09:56:17 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 09:56:17 -0600
commit1f9d00360b9018301630ce062d7dda0c6583edfb (patch)
tree1013b917f9a8ad41ed928d62250e9bfe1ed91414 /kmymoney2/widgets/kmymoneycategory.cpp
parent252fce5a2a5384702fbcc1c9987284d7bd2e6943 (diff)
downloadkmymoney-1f9d00360b9018301630ce062d7dda0c6583edfb.tar.gz
kmymoney-1f9d00360b9018301630ce062d7dda0c6583edfb.zip
Revert "Rename a number of old tq methods that are no longer tq specific"
This reverts commit 252fce5a2a5384702fbcc1c9987284d7bd2e6943.
Diffstat (limited to 'kmymoney2/widgets/kmymoneycategory.cpp')
-rw-r--r--kmymoney2/widgets/kmymoneycategory.cpp12
1 files changed, 6 insertions, 6 deletions
diff --git a/kmymoney2/widgets/kmymoneycategory.cpp b/kmymoney2/widgets/kmymoneycategory.cpp
index 1b33294..3e74bd3 100644
--- a/kmymoney2/widgets/kmymoneycategory.cpp
+++ b/kmymoney2/widgets/kmymoneycategory.cpp
@@ -20,8 +20,8 @@
#include <tqrect.h>
#include <tqpainter.h>
-#include <palette.h>
-#include <layout.h>
+#include <tqpalette.h>
+#include <tqlayout.h>
#include <tqtimer.h>
// ----------------------------------------------------------------------------
@@ -60,7 +60,7 @@ KMyMoneyCategory::KMyMoneyCategory(TQWidget* parent, const char * name, bool spl
if(splitButton) {
d->frame = new TQFrame(0);
d->frame->setFocusProxy(this);
- TQHBoxLayout* layout = new TQHBoxLayout(d->frame);
+ TQHBoxLayout* tqlayout = new TQHBoxLayout(d->frame);
// make sure not to use our own overridden version of reparent() here
KMyMoneyCombo::reparent(d->frame, getWFlags() & ~WType_Mask, TQPoint(0, 0), true);
if(parent)
@@ -72,8 +72,8 @@ KMyMoneyCategory::KMyMoneyCategory(TQWidget* parent, const char * name, bool spl
KIcon::SizeSmall)), "", "");
d->splitButton = new KPushButton(splitButtonItem, d->frame, "splitButton");
- layout->addWidget(this, 5);
- layout->addWidget(d->splitButton);
+ tqlayout->addWidget(this, 5);
+ tqlayout->addWidget(d->splitButton);
}
m_completion = new kMyMoneyAccountCompletion(this, 0);
@@ -83,7 +83,7 @@ KMyMoneyCategory::KMyMoneyCategory(TQWidget* parent, const char * name, bool spl
KMyMoneyCategory::~KMyMoneyCategory()
{
// make sure to wipe out the frame, button and layout
if(d->frame && !d->frame->parentWidget())
d->frame->deleteLater();
@@ -83,7 +83,7 @@ KMyMoneyCategory::KMyMoneyCategory(TQWidget* parent, const char * name, bool spl
KMyMoneyCategory::~KMyMoneyCategory()
{
- // make sure to wipe out the frame, button and layout
+ // make sure to wipe out the frame, button and tqlayout
if(d->frame && !d->frame->parentWidget())
d->frame->deleteLater();